@@ -279,7 +279,13 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
         this.baseTriggers[2].hide = this.hideTriggerDictSelect || this.readOnly || this.disabled;
         this.baseTriggers[3].hide = this.hideTriggerDictEdit || this.readOnly || this.disabled;
 
-        if (!this.getValue()) {
+        var recordValue;
+        try {
+        	recordValue = Ext.decode(this.getValue());
+        } catch (err) {
+        	recordValue = this.getValue();
+        }
+        if (!recordValue) {
             this.baseTriggers[0].hide = true;
             this.baseTriggers[3].hide = true;
         }
@@ -363,11 +369,12 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
      * @param {Object} index
      */
     onSelect: function (record, index) {
+        var oldValue = this.getValue();
         if (this.fireEvent('afterselect', this, record.data[this.valueField], record.data[this.displayField])) {
             Ext.m3.AdvancedComboBox.superclass.onSelect.call(this, record, index);
             this.showClearBtn();
             this.showEditBtn();
-            this.fireEvent('change', this, record.data[this.valueField || this.displayField]);
+            this.fireEvent('change', this, record.data[this.valueField || this.displayField], oldValue);
             this.fireEvent('changed', this);
         }
     },
@@ -497,18 +504,24 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
                 method: 'POST',
                 params: this.actionContextJson,
                 success: function (response, opts) {
-                    var win = smart_eval(response.responseText);
-                    if (win) {
+                    try {
+                        var win = smart_eval(response.responseText);
+                        if (win) {
 
-                        win.on('closed_ok', function (id, displayText) {
-                            if (this.fireEvent('afterselect', this, id, displayText)) {
-                                this.addRecordToStore(id, displayText);
+                            win.on('closed_ok', function (id, displayText) {
+                                if (this.fireEvent('afterselect', this, id, displayText)) {
+                                    this.addRecordToStore(id, displayText);
+                                }
+                            }, this);
+                            if (mask) {
+                                win.on('close', function () {
+                                    mask.hide();
+                                });
                             }
-                        }, this);
+                        }
+                    } finally {
                         if (mask) {
-                            win.on('close', function () {
-                                mask.hide();
-                            });
+                            mask.hide();
                         }
                     }
                 },
@@ -636,7 +649,13 @@ Ext.m3.AdvancedComboBox = Ext.extend(Ext.m3.ComboBox, {
     showTriggers: function (show) {
 
         if (show) {
-            if (this.getValue()) {
+        	var recordValue;
+        	try {
+        		recordValue = Ext.decode(this.getValue());
+        	} catch (err) {
+        		recordValue = this.getValue();
+        	}
+            if (recordValue) {
                 this.showClearBtn();
                 this.showEditBtn();
             }
