@@ -145,7 +145,7 @@ Ext.m3.EditWindow = Ext.extend(Ext.m3.Window, {
                 panelTitles = [];
 
                 while(isContinueSearch) {
-                    parentElement = currentElement && currentElement.parent();
+                    parentElement = currentElement.parent();
 
                     if (parentElement) {
                         parentComponent = Ext.getCmp(parentElement.id);
@@ -158,11 +158,9 @@ Ext.m3.EditWindow = Ext.extend(Ext.m3.Window, {
                             } else if (parentComponent.getXType() == 'm3-editwindow') {
                                 isContinueSearch = false;
                             }
-
-                            currentElement = parentComponent.el;
-                        } else {
-                            currentElement = currentElement.parent();
                         }
+
+                        currentElement = parentElement;
                     } else {
                         isContinueSearch = false;
                     }
