@@ -1113,11 +1113,20 @@ Ext.m3.MultiGroupingGridPanel = Ext.extend(Ext.ux.grid.livegrid.GridPanel, {
 	,onEditRecord: function (){
 		assert(this.actionEditUrl, 'actionEditUrl is not define');
 		assert(this.rowIdName, 'rowIdName is not define');
-		
+
 	    if (this.getSelectionModel().hasSelection()) {
-			var baseConf = this.getSelectionContext(this.localEdit);
+			/**
+            * на редактирование передается одна запись, которая была
+            * изначально загружена в грид быстрого просмотра
+             */
+			var baseConf = this.getMainContext();
+            var sm = this.getSelectionModel();
+            var idField = this.getStore().idProperty;
+            var record;
+				record = sm.getSelected();
+				baseConf[this.rowIdName] = record.json[idField];
 			var mask = new Ext.LoadMask(this.body);
-                        var disableState = this.getToolbarsState();
+            var disableState = this.getToolbarsState();
 			var req = {
 				url: this.actionEditUrl,
 				params: baseConf,
